#region Using declarations
using System;
using System.ComponentModel;
using System.Diagnostics;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.Xml.Serialization;
using NinjaTrader.Cbi;
using NinjaTrader.Data;
using NinjaTrader.Indicator;
using NinjaTrader.Gui.Chart;
using NinjaTrader.Strategy;
using System.IO;
using System.Collections.Generic;
using System.Linq;
#endregion

// This namespace holds all strategies and is required. Do not change it.
namespace NinjaTrader.Strategy
{ 
	/// <summary>
    /// Stocks and Commodities - April 2013 - Low-Frequency Trading
    /// </summary>
	/// 
    [Description("Stocks and Commodities - April 2013 - Low-Frequency Trading. For comparable results to the article, Strategy will require extensive history on ^ADV and ^DECL. See LowFrequencyATSExternalData for alternate implementation using supplied data ")]
    public class LowFrequencyATSCalculated : Strategy
    {		
        #region Variables
		private DataSeries 	adChange;
		private DataSeries 	cumAD;
		private DataSeries	cumAD1YearAvg;
		private int			validAdCounter;
        #endregion

        /// <summary>
        /// This method is used to configure the strategy and is called once before any strategy method is called.
        /// </summary>
        protected override void Initialize()
        {
            CalculateOnBarClose = true;
			Add("^ADV", PeriodType.Day, 1);
			Add("^DECL", PeriodType.Day, 1);
			adChange 		= new DataSeries(this);
			cumAD			= new DataSeries(this);
			cumAD1YearAvg	= new DataSeries(this);
        }

        /// <summary>
        /// Called on each bar update event (incoming tick)
        /// </summary>
        protected override void OnBarUpdate()
        {
			if (CurrentBars[0] < 0 || CurrentBars[1] < 0
				|| CurrentBars[2] < 0 || BarsInProgress != 0)
				return;
			
			if (BarsPeriod.Id != PeriodType.Day)
			{
				DrawTextFixed("DailyOnly", "Strategy is intended for daily intervals only", TextPosition.TopLeft);
				return;			
			}
			
			adChange.Set((Closes[1][0] - Closes[2][0]) / (Closes[1][0] + Closes[2][0]) * 1000);	
			
			if (adChange.ContainsValue(0))
			{
				cumAD.Set(cumAD[0] + adChange[0]);
				
				if (FirstTickOfBar)
					validAdCounter++;
				
				if (validAdCounter > 253)
				{
					cumAD1YearAvg.Set(SMA(cumAD, 253)[0]);
		
					if (cumAD[0] > cumAD1YearAvg[0])
						EnterLong();
					
					else
						ExitLong();
				}
			}
        }

        #region Properties
        #endregion
    }
}
