#region Using declarations
using System;
using System.ComponentModel;
using System.Diagnostics;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.Xml.Serialization;
using NinjaTrader.Cbi;
using NinjaTrader.Data;
using NinjaTrader.Indicator;
using NinjaTrader.Gui.Chart;
using NinjaTrader.Strategy;
using System.IO;
using System.Collections.Generic;
#endregion

// This namespace holds all strategies and is required. Do not change it.
namespace NinjaTrader.Strategy
{ 
	/// <summary>
    /// Stocks and Commodities - April 2013 - Low-Frequency Trading
    /// </summary>
	/// 
    [Description("Stocks and Commodities - April 2013 - Low-Frequency Trading. Strategy requires file McEwanwrkbk.txt contained within the packaged .zip")]
    public class LowFrequencyATSExternalData : Strategy
    {
		private class CustomData
		{
			public	DateTime 	date;
			public	double		djia;
			public	double		adv;
			public	double		decl;
			public	double		adChange;
			public	double		cumAD;
			public	double		cumAD1YearAvg;		
		}
		
        #region Variables
        private string 					filePath 		= Cbi.Core.UserDataDir.ToString() + "McEwanwrkbk.txt"; // Default setting for FilePath
		private int 					position 		= 254; // index 254 is 1st day of eligible cum1yearAvg data.
		private List<CustomData> 		customDataList	= new List<CustomData>();
		private System.IO.StreamReader	sr;
        #endregion

        /// <summary>
        /// This method is used to configure the strategy and is called once before any strategy method is called.
        /// </summary>
        protected override void Initialize()
        {
            CalculateOnBarClose = true;
        }

        /// <summary>
        /// Called on each bar update event (incoming tick)
        /// </summary>
	
        protected override void OnBarUpdate()
        {			
			if (BarsPeriod.Id != PeriodType.Day)
			{
				DrawTextFixed("DailyOnly", "Strategy is intended for daily intervals only", TextPosition.TopLeft);
				return;			
			}
			
			if (DateTime.Compare(Time[0], new DateTime(1966, 3, 1)) > 0) // for performance reasons, dont look at data earlier than needed.
			{
				for (int x = position; x < customDataList.Count; x++)
				{
					if (Time[0].Date == customDataList[x].date.Date) //found valid date to evaluate conditions. 
					{
						if (customDataList[x].cumAD > customDataList[x].cumAD1YearAvg)
							EnterLong();	
						else
							ExitLong();
						
						position = x;
						break;
					}
				}
			}
        }
		
		protected override void OnStartUp()
		{
			try
			{
				sr = new System.IO.StreamReader(FilePath);
				string 	line;
				int		lineCounter = 0;
				
				while ((line = sr.ReadLine()) != null) 
				{
					string [] 	split 			= line.Split(new Char [] {','});
					int 		splitCounter 	= 0;

					foreach (string s in split)
					{
						if (splitCounter == 0)
						{
							customDataList.Add(new CustomData());
							customDataList[lineCounter].date = DateTime.ParseExact(s, "M/d/yy", System.Globalization.CultureInfo.InvariantCulture);
						}
						else if (splitCounter == 1 && s!= null)
							customDataList[lineCounter].djia = double.Parse(s);
						else if (splitCounter == 2)
							customDataList[lineCounter].adv = double.Parse(s);
						else if (splitCounter == 3)
							customDataList[lineCounter].decl = double.Parse(s);	
						else if (splitCounter == 4)
							customDataList[lineCounter].adChange = double.Parse(s);
						else if (splitCounter == 5 && s != string.Empty)
							customDataList[lineCounter].cumAD = double.Parse(s);
						else if (splitCounter == 6)
						{
							if (s!= string.Empty)
								customDataList[lineCounter].cumAD1YearAvg = double.Parse(s);
							lineCounter++;
						}
						splitCounter++;
					}	
				}
				
				if (sr != null)
				{
					sr.Dispose();
					sr = null;
				}
			}
						
			catch (FileNotFoundException e)
			{
				Log(this + @" Could not find file. Please extract McEwanwrkbk.txt from April2013SC.zip into: " + FilePath, LogLevel.Error);				
			}

			catch (Exception e)
			{
				Log(e.ToString(), LogLevel.Error);
			}
		}
		
		protected override void OnTermination()
		{
			if (sr != null)
			{
				sr.Dispose();
				sr = null;
			}
		}
		
		public override string ToString()
		{
			return Name;
		}
		
        #region Properties
		[Description("Location of external data required by strategy")]
        [GridCategory("Parameters")]
        public string FilePath
        {
            get { return filePath; }
            set { filePath = value; }
        }
        #endregion
    }
}
